==> manaplus_1.3.9.15.orig.tar.xz: manaplus-1.3.9.15/src/resources/sdl2softwareimagehelper.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef RESOURCES_SDL2SOFTWAREIMAGEHELPER_H
#define RESOURCES_SDL2SOFTWAREIMAGEHELPER_H

#ifdef USE_SDL2

#include "localconsts.h"

#include "resources/imagehelper.h"

#include <SDL.h>

class Dye;
class Image;

/**
 * Defines a class for loading and storing images.
 */
class SDL2SoftwareImageHelper final : public ImageHelper
{
    friend class Image;

    public:
        SDL2SoftwareImageHelper()
        { }

        A_DELETE_COPY(SDL2SoftwareImageHelper)

        virtual ~SDL2SoftwareImageHelper()
        { }

        /**
         * Loads an image from an SDL_RWops structure and recolors it.
         *
         * @param rw         The SDL_RWops to load the image from.
         * @param dye        The dye used to recolor the image.
         *
         * @return <code>NULL</code> if an error occurred, a valid pointer
         *         otherwise.
         */
        Image *load(SDL_RWops *const rw,
                    Dye const &dye) const override A_WARN_UNUSED;

        /**
         * Loads an image from an SDL surface.
         */
        Image *load(SDL_Surface *const tmpImage) const override A_WARN_UNUSED;

        Image *createTextSurface(SDL_Surface *const tmpImage,
                                 const int width, const int height,
                                 const float alpha)
                                 const override A_WARN_UNUSED;

        static void SDLSetEnableAlphaCache(const bool n)
        { mEnableAlphaCache = n; }

        static bool SDLGetEnableAlphaCache() A_WARN_UNUSED
        { return mEnableAlphaCache; }

        static SDL_Surface* SDLDuplicateSurface(SDL_Surface *const tmpImage)
                                                A_WARN_UNUSED;

        SDL_Surface *create32BitSurface(int width, int height) const override;

        static int combineSurface(SDL_Surface *const src,
                                  SDL_Rect *const srcrect,
                                  SDL_Surface *const dst,
                                  SDL_Rect *const dstrect);

        static void setFormat(SDL_PixelFormat *const format)
        {
            mFormat = format;
            if (mFormat)
            {
                mFormat->Amask = ~(format->Rmask
                    | format->Gmask | format->Bmask);
            }
        }

    protected:
        /** SDL_Surface to SDL_Surface Image loader */
        Image *_SDLload(SDL_Surface *tmpImage) const A_WARN_UNUSED;

        static bool mEnableAlphaCache;
        static SDL_PixelFormat *mFormat;
};

#endif  // USE_SDL2
#endif  // RESOURCES_SDL2SOFTWAREIMAGEHELPER_H

==> manaplus_1.3.9.29.orig.tar.xz: manaplus-1.3.9.29/src/resources/sdl2softwareimagehelper.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2004-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef RESOURCES_SDL2SOFTWAREIMAGEHELPER_H
#define RESOURCES_SDL2SOFTWAREIMAGEHELPER_H

#ifdef USE_SDL2

#include "localconsts.h"

#include "resources/imagehelper.h"

#include <SDL.h>

class Dye;
class Image;

/**
 * Defines a class for loading and storing images.
 */
class SDL2SoftwareImageHelper final : public ImageHelper
{
    friend class Image;

    public:
        SDL2SoftwareImageHelper() :
            ImageHelper()
        { }

        A_DELETE_COPY(SDL2SoftwareImageHelper)

        ~SDL2SoftwareImageHelper()
        { }

        /**
         * Loads an image from an SDL_RWops structure and recolors it.
         *
         * @param rw         The SDL_RWops to load the image from.
         * @param dye        The dye used to recolor the image.
         *
         * @return <code>NULL</code> if an error occurred, a valid pointer
         *         otherwise.
         */
        Image *load(SDL_RWops *const rw,
                    Dye const &dye) const override A_WARN_UNUSED;

        /**
         * Loads an image from an SDL surface.
         */
        Image *load(SDL_Surface *const tmpImage) const override A_WARN_UNUSED;

        Image *createTextSurface(SDL_Surface *const tmpImage,
                                 const int width, const int height,
                                 const float alpha)
                                 const override A_WARN_UNUSED;

        static void SDLSetEnableAlphaCache(const bool n)
        { mEnableAlphaCache = n; }

        static bool SDLGetEnableAlphaCache() A_WARN_UNUSED
        { return mEnableAlphaCache; }

        static SDL_Surface* SDLDuplicateSurface(SDL_Surface *const tmpImage)
                                                A_WARN_UNUSED;

        SDL_Surface *create32BitSurface(int width, int height) const override;

        static int combineSurface(SDL_Surface *const src,
                                  SDL_Rect *const srcrect,
                                  SDL_Surface *const dst,
                                  SDL_Rect *const dstrect);

        static void setFormat(SDL_PixelFormat *const format)
        {
            mFormat = format;
            if (mFormat)
            {
                mFormat->Amask = ~(format->Rmask
                    | format->Gmask | format->Bmask);
            }
        }

    protected:
        /** SDL_Surface to SDL_Surface Image loader */
        Image *_SDLload(SDL_Surface *tmpImage) const A_WARN_UNUSED;

        static bool mEnableAlphaCache;
        static SDL_PixelFormat *mFormat;
};

#endif  // USE_SDL2
#endif  // RESOURCES_SDL2SOFTWAREIMAGEHELPER_H
